@@ -29,6 +29,9 @@ orbit = Resource(library, 'js/jquery.foundation.orbit.js', depends=[jquery], bot
 reveal = Resource(library, 'js/jquery.foundation.reveal.js', depends=[jquery], bottom=True)
 tabs = Resource(library, 'js/jquery.foundation.tabs.js', depends=[jquery], bottom=True)
 tooltips = Resource(library, 'js/jquery.foundation.tooltips.js', depends=[jquery, modernizr], bottom=True)
-topbar_css = Resource(library, 'css/topbar.min.css')
-topbar = Resource(library, 'js/jquery.foundation.topbar.js', depends=[jquery, modernizr, topbar_css], bottom=True)
 offcanvas = Resource(library, 'js/jquery.offcanvas.js', depends=[jquery], bottom=True)
+
+# topbar
+topbar_css = Resource(library, 'css/topbar.min.css')
+topbar_js = Resource(library, 'js/jquery.foundation.topbar.js', depends=[jquery, modernizr], bottom=True)
+topbar = Group([topbar_css, topbar_js])
